translate.storage.placeables.lisa

Package translate :: Package storage :: Package placeables :: Module lisa |
[hide private]
[frames] | no frames]

# Module lisa

source code

Functions | [hide private]
make_empty_replacement_placeable(klass, node, xml_space=`'``preserve``'`) | source code
make_g_placeable(klass, node, xml_space=`'``default``'`) | source code
not_yet_implemented(klass, node, xml_space=`'``preserve``'`) | source code
make_unknown(klass, node, xml_space=`'``preserve``'`) | source code
make_placeable(node, xml_space) | source code
as_unicode(string) | source code
xml_to_strelem(dom_node, xml_space=`'``preserve``'`) | source code
placeable_as_dom_node(placeable, tagname) | source code
unknown_placeable_as_dom_node(placeable) | source code
xml_append_string(node, string) | source code
strelem_to_xml(parent_node, elem) | source code
parse_xliff(pstr) | source code

Variables | [hide private]
| _class_dictionary = ``{``u'``bx``'``:` `(`<class 'translate.storage.placeab`...``
| _placeable_dictionary = ``{`<class 'translate.storage.placeables.`...``
| __package__ = ``'``translate.storage.placeables``'``

Imports: etree, normalize_xml_space, base, xliff, StringElem, misc

Variables Details | [hide private]

  ### _class_dictionary Value:
      {u'bx':(xliff.Bx, make_empty_replacement_placeable), u'ex':(xliff.Ex,
      make_empty_replacement_placeable), u'g':(xliff.G, make_g_placeable), u
      'x':(xliff.X, make_empty_replacement_placeable),}

  ### _placeable_dictionary Value:
      {xliff.Bpt: lambda placeable: placeable_as_dom_node(placeable, 'bpt'),
       xliff.Bx: lambda placeable: placeable_as_dom_node(placeable, 'bx'), x
      liff.Ept: lambda placeable: placeable_as_dom_node(placeable, 'ept'), x
      liff.Ex: lambda placeable: placeable_as_dom_node(placeable, 'ex'), xli
      ff.G: lambda placeable: placeable_as_dom_node(placeable, 'g'), xliff.I
      t: lambda placeable: placeable_as_dom_node(placeable, 'it'), xliff.Ph:
       lambda placeable: placeable_as_dom_node(placeable, 'ph'), xliff.Sub:
      lambda placeable: placeable_as_dom_node(placeable, 'sub'), xliff.X: la
      ...